@@ -4,4 +4,4 @@ from dragoneye.cloud_scanner.aws.aws_scanner import AwsScanner
 from dragoneye.cloud_scanner.azure.azure_scanner import AzureScanner
 from dragoneye.cloud_scanner.aws.aws_session_factory import AwsSessionFactory
 from dragoneye.cloud_scanner.azure.azure_authorizer import AzureAuthorizer
-from dragoneye.utils.app_logger import logger
+from dragoneye.utils.app_logger import logger, add_file_handler
