@@ -1,17 +1,6 @@
 import os
 
-from dragoneye.cloud_scanner.base_cloud_scanner import CloudCredentials, CloudScanSettings, CloudProvider
-
-
-class AzureCredentials(CloudCredentials):
-    def __init__(self,
-                 tenant_id: str,
-                 client_id: str,
-                 client_secret: str
-                 ):
-        self.tenant_id: str = tenant_id
-        self.client_id: str = client_id
-        self.client_secret: str = client_secret
+from dragoneye.cloud_scanner.base_cloud_scanner import CloudScanSettings, CloudProvider
 
 
 class AzureCloudScanSettings(CloudScanSettings):
@@ -20,11 +9,11 @@ class AzureCloudScanSettings(CloudScanSettings):
                  subscription_id: str,
                  account_name: str,
                  output_path: str = os.getcwd(),
-                 should_clean_before_collect: bool = True
+                 should_clean_before_scan: bool = True
                  ):
         super().__init__(cloud_provider=CloudProvider.AZURE,
                          account_name=account_name,
-                         should_clean_before_collect=should_clean_before_collect,
+                         should_clean_before_scan=should_clean_before_scan,
                          output_path=output_path,
                          commands_path=commands_path)
         self.subscription_id = subscription_id
